using System.Numerics;
using System.Threading;
using System.Threading.Tasks;

namespace FastRng.Distributions;

public interface IDistribution<TNum> where TNum : IFloatingPointIeee754<TNum>
{
    public ValueTask<TNum> GetDistributedValue(CancellationToken token);
        
    public ValueTask<uint> NextNumber(uint rangeStart, uint rangeEnd, CancellationToken cancel = default);
        
    public ValueTask<ulong> NextNumber(ulong rangeStart, ulong rangeEnd, CancellationToken cancel = default);
        
    public ValueTask<TNum> NextNumber(TNum rangeStart, TNum rangeEnd, CancellationToken cancel = default);
        
    public ValueTask<TNum> NextNumber(CancellationToken cancel = default);
        
    public ValueTask<bool> HasDecisionBeenMade(TNum above, TNum below, CancellationToken cancel = default);
}